/**
 * @module botbuilder-adapter-vonage
 */
/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
import { BotWorker } from "botkit";
import Vonage from "@vonage/server-sdk";
/**
 * controller.spawn() https://botkit.ai/docs/v4/reference/core.html#BotWorker
 * This is a specialized version of [Botkit's core BotWorker class](core.md#BotWorker) that includes additional methods for interacting with Vonage SMS.
 * It includes all functionality from the base class, as well as the extension methods below.
 *
 * When using the VonageAdapter with Botkit, all `bot` objects passed to handler functions will include these extensions.
 */ export declare class VonageBotWorker extends BotWorker {
    /**
     * A copy of the Vonage API client. https://github.com/Vonage/vonage-node-sdk/tree/beta
     */
    api: Vonage;
    /**
     * Start a conversation with a given user identified by their phone number. Useful for sending pro-active messages:
     *
     * NOTE:
     * [BotWorker](https://botkit.ai/docs/v4/reference/core.html#BotWorker) <<< GO HERE FIRST!
     *
     * [controller.spawn()](https://botkit.ai/docs/v4/reference/core.html#spawn)
     * - "Creates a new BotWorker Instance"
     * - "Used to respond to messages or generate new outbound messages"
     *
     * ```javascript
     * // Spawn a worker
     * let bot = await controller.spawn();
     *
     * // Start a conversation with that phone number
     * await bot.startConversationWithUser(MY_PHONE_NUMBER);
     *
     * // Send a message to that phone number
     * await bot.say('Hello There!');
     *
     * // Begin a dialog in the 1:1 context
     * await bot.beginDialog(ANOTHER_DIALOG)
     * ```
     *
     * @param userId A phone number in the form +1XXXYYYZZZZ
     */
    startConversationWithUser(userId: string): Promise<any>;
}
