"use strict";
/**
 * @module botbuilder-adapter-vonage
 */
/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.VonageBotWorker = void 0;
const botkit_1 = require("botkit");
/**
 * controller.spawn() https://botkit.ai/docs/v4/reference/core.html#BotWorker
 * This is a specialized version of [Botkit's core BotWorker class](core.md#BotWorker) that includes additional methods for interacting with Vonage SMS.
 * It includes all functionality from the base class, as well as the extension methods below.
 *
 * When using the VonageAdapter with Botkit, all `bot` objects passed to handler functions will include these extensions.
 */ class VonageBotWorker extends botkit_1.BotWorker {
    /**
     * Start a conversation with a given user identified by their phone number. Useful for sending pro-active messages:
     *
     * NOTE:
     * [BotWorker](https://botkit.ai/docs/v4/reference/core.html#BotWorker) <<< GO HERE FIRST!
     *
     * [controller.spawn()](https://botkit.ai/docs/v4/reference/core.html#spawn)
     * - "Creates a new BotWorker Instance"
     * - "Used to respond to messages or generate new outbound messages"
     *
     * ```javascript
     * // Spawn a worker
     * let bot = await controller.spawn();
     *
     * // Start a conversation with that phone number
     * await bot.startConversationWithUser(MY_PHONE_NUMBER);
     *
     * // Send a message to that phone number
     * await bot.say('Hello There!');
     *
     * // Begin a dialog in the 1:1 context
     * await bot.beginDialog(ANOTHER_DIALOG)
     * ```
     *
     * @param userId A phone number in the form +1XXXYYYZZZZ
     */
    startConversationWithUser(userId) {
        return __awaiter(this, void 0, void 0, function* () {
            // changeContext() - Alter the context in which a bot instance will send messages.
            // Use this method to create or adjust a bot instance so that it can send messages to a predefined user/channel combination.
            return this.changeContext({
                channelId: "vonage-sms",
                conversation: { id: userId },
                bot: { id: this.controller.getConfig("vonage_number"), name: "bot" },
                user: { id: userId },
            });
        });
    }
}
exports.VonageBotWorker = VonageBotWorker;
//# sourceMappingURL=botworker.js.map